1#ifndef __MATH_DUDXYZ_KERNEL_H__
2#define __MATH_DUDXYZ_KERNEL_H__
46template<
typename T, const
int LX, const
int CHUNKS >
79 while(l < (
LX *
LX *
LX)) {
90 for (
int n = 0; n <
nchunks; n++) {
94 const int k =
jk /
LX;
100 for (
int l = 0; l <
LX; l++) {
114template<
typename T, const
int LX, const
int EB >
133 static_assert(
sizeof(
shu) +
138 "kstep block exceeds the LDS budget");
177 for (
int k = 0;
k <
LX; ++
k) {
182 for (
int l = 0; l <
LX; l++) {
190 for (
int l = 0; l <
LX; l++) {
218#if defined(__gfx90a__) || defined(__gfx942__)
220template<
typename T, const
int LX, const
int NWF >
241 "wavefronts per block must split evenly over the elements");
251 static_assert(
sizeof(
shdx) +
sizeof(
shdy) +
sizeof(
shdz) +
254 "mfma block exceeds the shared memory budget");
258 const int tid = wf * 64 +
lane;
261 const int eb = wf /
WPE;
290 mfma_contract_sel<T, LX, 0, false, false, WPE>::run(
shr +
sh,
shdx,
292 mfma_contract_sel<T, LX, 1, false, false, WPE>::run(
shs +
sh,
shdy,
294 mfma_contract_sel<T, LX, 2, false, false, WPE>::run(
sht +
sh,
shdz,
301 const int gp = p +
ele;
321template<
typename T, const
int LX, const
int NWF >
324 const T *,
const T *,
const T *,
const T *,
328#if defined(__gfx90a__) || defined(__gfx942__)
331#define NEKO_DUDXYZ_MFMA_DISPATCH(TYPE, LXV) \
332 template< const int NWF > \
333 struct dudxyz_mfma_dispatch< TYPE, LXV, NWF > { \
334 __device__ static void run(TYPE * du, \
342 const TYPE * jacinv, \
344 dudxyz_mfma_elem< TYPE, LXV, NWF >(du, u, dr, ds, dt, dx, dy, dz, \
376template<
typename T, const
int LX, const
int NWF >
389 dudxyz_mfma_dispatch< T, LX, NWF >::run(du,
u,
dr,
ds,
dt,
dx,
dy,
dz,
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dz
__global__ void const T *__restrict__ const T *__restrict__ dr
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dy
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ ds
__shared__ T shdy[LX *LX]
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dt
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ dx
__shared__ T shdx[LX *LX]
__shared__ T shdz[LX *LX]
__global__ void dudxyz_kernel_1d(T *__restrict__ du, const T *__restrict__ u, const T *__restrict__ dr, const T *__restrict__ ds, const T *__restrict__ dt, const T *__restrict__ dx, const T *__restrict__ dy, const T *__restrict__ dz, const T *__restrict__ jacinv)
__global__ void const T *__restrict__ u
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const int nelv
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ jacinv
#define NEKO_EB_BOUNDS(NT)
__global__ void __launch_bounds__((LX *LX *EB), 3) dudxyz_kernel_kstep(T *__restrict__ du
#define NEKO_MFMA_EB_N(NWF, LX)
static __device__ void run(T *, const T *, const T *, const T *, const T *, const T *, const T *, const T *, const T *, const int)